Composes
========

``cornice_sphinx`` does `not <https://github.com/Cornices/cornice.ext.sphinx/issues/15>`_ yet have
the ability to render documentation for the ``/composes/`` API, so we will include docblock
documentation for that service here instead.


.. autoclass:: bodhi.server.services.composes.Composes
